@@ -9,7 +9,7 @@ def encrypt(key: str, content: str):
     return base64.b64encode(PKCS1_OAEP.new(key).encrypt(content.encode('utf-8'))).decode('utf-8')
 
 
-def decrypt(pkey: str, content: str):
+def decrypt(key: str, content: str):
     pkey = RSA.import_key(key)
     return PKCS1_OAEP.new(pkey).decrypt(base64.b64decode(content.encode('utf-8'))).decode('utf-8')
 
